import { program, Command } from '@/program.ts';
import { getConfig, writeConfig } from '@/module/get-config.ts';
import { queryLogin, queryMe, switchOrg, switchMe } from '@/query/index.ts';
import inquirer from 'inquirer';
import { runApp } from '../app-run.ts';
// 导入 login 命令

// 定义login命令，支持 `-u` 和 `-p` 参数来输入用户名和密码
const loginCommand = new Command('login')
  .description('Login to the application')
  .option('-u, --username <username>', 'Specify username')
  .option('-p, --password <password>', 'Specify password')
  .action(async (options) => {
    const config = getConfig();
    let { username, password } = options;

    // 如果没有传递参数，则通过交互式输入
    if (!username || !password) {
      const answers = await inquirer.prompt([
        {
          type: 'input',
          name: 'username',
          message: 'Enter your username:',
          when: () => !username, // 当 username 为空时，提示用户输入
        },
        {
          type: 'password',
          name: 'password',
          message: 'Enter your password:',
          mask: '*', // 隐藏输入的字符
          when: () => !password, // 当 password 为空时，提示用户输入
        },
      ]);
      username = answers.username || username;
      password = answers.password || password;
    }
    if (config.token) {
      const res = await showMe(false);
      if (res.code === 200) {
        const data = res.data;
        if (data.username === username) {
          console.log('Already Login For', data.username);
          return;
        }
      }
    }

    const res = await queryLogin(username, password);
    if (res.code === 200) {
      const { token } = res.data;
      writeConfig({ ...config, token });
      console.log('welcome', username);
    } else {
      console.log('登录失败', res.message || '');
    }
  });

program.addCommand(loginCommand);

const showMe = async (show = true) => {
  const me = await queryMe();
  if (show) {
    // save me to config
    const meSet = await runApp({ path: 'config', key: 'meSet', payload: { data: me.data } });
    if (me.code === 200) {
      console.log('Me', me.data);
    } else {
      const config = getConfig();
      console.log('Show Me failed', me.message);
      writeConfig({ ...config, token: '' });
    }
  }
  return me;
};

const switchOrgCommand = new Command('switchOrg').argument('<username>', 'Switch to another organization').action(async (options) => {
  // console.log('options', options);
  const config = getConfig();
  if (!config.token) {
    console.log('Please login first');
    return;
  }
  const meGet = await runApp({ path: 'config', key: 'meGet' });
  if (meGet.code !== 200) {
    console.log('Please login first');
    return;
  }
  const me = meGet.data?.value || {};
  if (me?.username === options) {
    // console.log('Already in', options);
    console.log('success switch to', options);
    return;
  }
  const res = await switchOrg(options);
  if (res.code === 200) {
    const token = res.data.token;
    writeConfig({ ...config, token });
    console.log('Switch Org Success');
    await showMe();
  } else {
    console.log('Switch Org Failed', res.message || '');
  }
});

program.addCommand(switchOrgCommand);

const switchMeCommand = new Command('switchMe').action(async () => {
  const config = getConfig();
  if (!config.token) {
    console.log('Please login first');
    return;
  }
  const res = await switchMe();
  if (res.code === 200) {
    const token = res.data.token;
    writeConfig({ ...config, token });
    console.log('Switch Me Success');
    showMe();
  } else {
    console.log('Switch Me Failed', res.message || '');
  }
});
program.addCommand(switchMeCommand);

const command = new Command('me').description('').action(async () => {
  await showMe();
});

program.addCommand(command);
