import { program as app, Command } from '@/program.ts';
import inquirer from 'inquirer';
import { query } from '../module/index.ts';
import chalk from 'chalk';
import util from 'util';

// web 开发模块
const command = new Command('router')
  .description('router get')
  .option('-p, --path <path>', '退出进程')
  .option('-k, --key <key>', '启动进程')
  .action(async (options) => {
    let { path, key } = options;
    // 如果没有传递参数，则通过交互式输入
    if (!path || !key) {
      const answers = await inquirer.prompt([
        {
          type: 'input',
          name: 'path',
          message: 'Enter your path:',
          when: () => !path, // 当 username 为空时，提示用户输入
        },
        {
          type: 'input',
          name: 'key',
          message: 'Enter your key:',
          when: () => !key, // 当 password 为空时，提示用户输入
        },
      ]);
      path = answers.path || path;
      key = answers.key || key;
    }

    const res = await query.post({ path, key });
    if (res?.code === 200) {
      const data = res.data.map((item: any) => {
        // return `id: ${item.id}, title: ${item.title}`;

        return {
          id: item.id,
          title: item.title,
        };
      });
      console.log(chalk.green(util.inspect(data, { colors: true, depth: 4 })));
    } else {
      console.log('error', res.message || '');
    }
  });
app.addCommand(command);
